/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

/*
 *  Medusa
 *
 *  Copyright (C) 2000 Eazel, Inc.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Maciej Stachowiak <mjs@eazel.com>
 *
 *  medusa-lock-file-paths.h -  Paths for common lock files.
 */

#ifndef MEDUSA_LOCK_FILE_PATHS_H
#define MEDUSA_LOCK_FILE_PATHS_H

#define MEDUSA_FILE_INDEX_READ_LOCK_FILE "/var/lock/medusa-db-read"
#define MEDUSA_FILE_INDEX_WRITE_LOCK_FILE "/var/lock/medusa-db-write"

#endif /* MEDUSA_LOCK_FILE_PATHS_H */
